package cn.wisenergy.chnmuseum.party.model;

import cn.wisenergy.chnmuseum.party.common.validator.groups.Add;
import cn.wisenergy.chnmuseum.party.common.validator.groups.Update;
import com.baomidou.mybatisplus.annotation.*;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.*;
import lombok.experimental.Accessors;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * <p>
 * 视频
 * </p>
 *
 * @author Danny Lee
 * @since 2021-03-16
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@TableName("asset")
@ApiModel(value = "视频", description = "视频")
public class Asset implements Serializable {

    private static final long serialVersionUID = 1L;

    @ApiModelProperty("视频ID")
    @TableId(value = "id", type = IdType.ASSIGN_ID)
    @NotNull(message = "视频ID不能为空", groups = {Update.class})
    private String id;

    @ApiModelProperty("视频名称")
    @TableField("name")
    @NotBlank(message = "视频名称不能为空", groups = {Add.class, Update.class})
    private String name;

    @ApiModelProperty("视频版权方ID")
    @TableField("asset_copyright_owner_id")
    @NotBlank(message = "视频版权方ID不能为空", groups = {Add.class, Update.class})
    private String assetCopyrightOwnerId;

    @ApiModelProperty("视频类别ID")
    @TableField(value = "asset_type_id", updateStrategy = FieldStrategy.IGNORED)
    @NotBlank(message = "视频类别ID不能为空", groups = {Add.class, Update.class})
    private String assetTypeId;

    @ApiModelProperty("视频缩略图")
    @TableField("thumbnail")
    @NotBlank(message = "视频缩略图不能为空", groups = {Add.class, Update.class})
    private String thumbnail;

    @ApiModelProperty("视频链接")
    @TableField("video_url")
    private String videoUrl;

    @ApiModelProperty("审核状态")
    @TableField("audit_status")
    private String auditStatus;

    @ApiModelProperty("创建日期")
    @TableField(value = "create_time", fill = FieldFill.INSERT)
    private LocalDateTime createTime;

    @ApiModelProperty("修改日期")
    @TableField(value = "update_time", fill = FieldFill.INSERT_UPDATE)
    private LocalDateTime updateTime;

    @ApiModelProperty("视频分类")
    @TableField(exist = false)
    private String assetTypeName;

    @ApiModelProperty("版权方")
    @TableField(exist = false)
    private String assetCopyrightOwnerName;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getAssetCopyrightOwnerId() {
        return assetCopyrightOwnerId;
    }

    public void setAssetCopyrightOwnerId(String assetCopyrightOwnerId) {
        this.assetCopyrightOwnerId = assetCopyrightOwnerId;
    }

    public String getAssetTypeId() {
        return assetTypeId;
    }

    public void setAssetTypeId(String assetTypeId) {
        this.assetTypeId = assetTypeId;
    }

    public String getThumbnail() {
        return thumbnail;
    }

    public void setThumbnail(String thumbnail) {
        this.thumbnail = thumbnail;
    }

    public String getVideoUrl() {
        return videoUrl;
    }

    public void setVideoUrl(String videoUrl) {
        this.videoUrl = videoUrl;
    }

    public String getAuditStatus() {
        return auditStatus;
    }

    public void setAuditStatus(String auditStatus) {
        this.auditStatus = auditStatus;
    }

    public LocalDateTime getCreateTime() {
        return createTime;
    }

    public void setCreateTime(LocalDateTime createTime) {
        this.createTime = createTime;
    }

    public LocalDateTime getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(LocalDateTime updateTime) {
        this.updateTime = updateTime;
    }

    public String getAssetTypeName() {
        return assetTypeName;
    }

    public void setAssetTypeName(String assetTypeName) {
        this.assetTypeName = assetTypeName;
    }

    public String getAssetCopyrightOwnerName() {
        return assetCopyrightOwnerName;
    }

    public void setAssetCopyrightOwnerName(String assetCopyrightOwnerName) {
        this.assetCopyrightOwnerName = assetCopyrightOwnerName;
    }
}
